/*
    Quick Log Entry (qle)
    Copyright (C) 2025  Thomas Cort

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include <string.h>
#include <time.h>

#include "adif.h"
#include "parse.h"

void qle_adif_data_specifier(FILE *output, char *field, char *value, char *data_type_indicator) {
	if (data_type_indicator == NULL) {
		fprintf(output, "<%s:%ld>%s", field, strlen(value), value);
	} else {
		fprintf(output, "<%s:%ld:%s>%s", field, strlen(value), data_type_indicator, value);
	}
}

void qle_adif_header(FILE *output, time_t input_mtime, char *input_file) {

	time_t now;
	struct tm *utc;
	struct tm *input_mtime_utc;
	char created_timestamp[32];
	char input_last_modified[32];

	now = time(NULL);
	utc = gmtime(&now);

	memset(created_timestamp, '\0', sizeof(created_timestamp));
	strftime(created_timestamp, sizeof(created_timestamp)-1, "%Y%m%d %H%M%S", utc);

	input_mtime_utc = gmtime(&input_mtime);

	memset(input_last_modified, '\0', sizeof(input_last_modified));
	strftime(input_last_modified, sizeof(input_last_modified)-1, "%Y%m%d %H%M%S", input_mtime_utc);

	fprintf(output, "# Converted from Quick Log Entry format %s to ADIF format %s by %s%s", QLE_VERSION, ADIF_VERSION, PACKAGE_STRING, QLE_ADIF_EOL);
	qle_adif_data_specifier(output, "adif_version", ADIF_VERSION, NULL);
	fprintf(output, "%s", QLE_ADIF_EOL);
	qle_adif_data_specifier(output, "created_timestamp", created_timestamp, NULL);
	fprintf(output, "%s", QLE_ADIF_EOL);
	qle_adif_data_specifier(output, "app_qle_input_file", input_file, QLE_ADIF_DTI_STRING);
	fprintf(output, "%s", QLE_ADIF_EOL);
	qle_adif_data_specifier(output, "app_qle_input_last_modified", input_last_modified, QLE_ADIF_DTI_STRING);
	fprintf(output, "%s", QLE_ADIF_EOL);
	qle_adif_data_specifier(output, "programid", PACKAGE_NAME, NULL);
	fprintf(output, "%s", QLE_ADIF_EOL);
	qle_adif_data_specifier(output, "programversion", PACKAGE_VERSION, NULL);
	fprintf(output, "%s", QLE_ADIF_EOL);
	fprintf(output, "<eoh>%s%s", QLE_ADIF_EOL, QLE_ADIF_EOL);
}

void qle_adif_record(FILE *output, int compact) {

	int i;

	char *adif_fs;
	char *adif_rs;

	adif_fs = compact == 1 ? QLE_ADIF_FS_COMPACT : QLE_ADIF_FS_DEFAULT;
	adif_rs = compact == 1 ? QLE_ADIF_RS_COMPACT : QLE_ADIF_RS_DEFAULT;

	if (qle_fields[QLE_NFIELDS - 1].value[0] == '\0') {
		return; /* no call sign nothing to do */
	}

	for (i = 0; i < QLE_NFIELDS; i++) {
		if (qle_fields[i].value[0] != '\0') {
			qle_adif_data_specifier(output, qle_fields[i].adif_field, qle_fields[i].value, NULL);
			fprintf(output, "%s", adif_fs);
		}
	}
	fprintf(output, "<eor>%s", adif_rs);

	for (i = 0; i < QLE_NFIELDS; i++) {
		if (qle_fields[i].preserve == 0) {
			memset(qle_fields[i].value, '\0', QLE_TOKEN_SIZE);
		}
	}
	qle_rst_defaults();
}

