/*
    Quick Log Entry (qle)
    Copyright (C) 2025  Thomas Cort

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdlib.h>

#include "band.h"

static struct qle_band_freq qle_band_freq_ranges[] = {
	{ .band = "2190M", .min = 0.1357, .max = 0.1378 },
	{ .band = "630M", .min = 0.472, .max = 0.479 },
	{ .band = "560M", .min = 0.501, .max = 0.504 },
	{ .band = "160M", .min = 1.8, .max = 2.0 },
	{ .band = "80M", .min = 3.5, .max = 4.0 },
	{ .band = "60M", .min = 5.06, .max = 5.45 },
	{ .band = "40M", .min = 7.0, .max = 7.3 },
	{ .band = "30M", .min = 10.1, .max = 10.15 },
	{ .band = "20M", .min = 14.0, .max = 14.35 },
	{ .band = "17M", .min = 18.068, .max = 18.168 },
	{ .band = "15M", .min = 21.0, .max = 21.45 },
	{ .band = "12M", .min = 24.890, .max = 24.99 },
	{ .band = "10M", .min = 28.0, .max = 29.7 },
	{ .band = "8M", .min = 40, .max = 45 },
	{ .band = "6M", .min = 50, .max = 54 },
	{ .band = "5M", .min = 54.000001, .max = 69.9 },
	{ .band = "4M", .min = 70, .max = 71 },
	{ .band = "2M", .min = 144, .max = 148 },
	{ .band = "1.25M", .min = 222, .max = 225 },
	{ .band = "70cM", .min = 420, .max = 450 },
	{ .band = "33cM", .min = 902, .max = 928 },
	{ .band = "23cM", .min = 1240, .max = 1300 },
	{ .band = "13cM", .min = 2300, .max = 2450 },
	{ .band = "9cM", .min = 3300, .max = 3500 },
	{ .band = "6cM", .min = 5650, .max = 5925 },
	{ .band = "3cM", .min = 10000, .max = 10500 },
	{ .band = "1.25cM", .min = 24000, .max = 24250 },
	{ .band = "6mM", .min = 47000, .max = 47200 },
	{ .band = "4mM", .min = 75500, .max = 81000 },
	{ .band = "2.5mM", .min = 119980, .max = 123000 },
	{ .band = "2mM", .min = 134000, .max = 149000 },
	{ .band = "1mM", .min = 241000, .max = 250000 },
	{ .band = "submM", .min = 300000, .max = 7500000 }
};

#define QLE_NBAND_FREQ_RANGES ((int) (sizeof(qle_band_freq_ranges)/sizeof(qle_band_freq_ranges[0])))


char *qle_freq_to_band(char *freq) {

	int i;
	double f;

	f = strtod(freq, NULL);

	for (i = 0; i < QLE_NBAND_FREQ_RANGES; i++) {
		if (qle_band_freq_ranges[i].min <= f && f <= qle_band_freq_ranges[i].max) {
			return qle_band_freq_ranges[i].band;
		}
	}

	return NULL;
}
