/*
    Quick Log Entry (qle)
    Copyright (C) 2025  Thomas Cort

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifndef QLE_PARSE_H
#define QLE_PARSE_H

#include <stdio.h> /* for FILE* */
#include <time.h> /* for time_t */

#define QLE_TOKEN_SIZE (512)

#define QLE_NFIELDS (40)

#define QLE_FIELD_INDEX_MODE (0)
#define QLE_FIELD_INDEX_RST_SENT (1)
#define QLE_FIELD_INDEX_RST_RCVD (2)
#define QLE_FIELD_INDEX_BAND (3)
#define QLE_FIELD_INDEX_SIG (4)
#define QLE_FIELD_INDEX_SIG_INFO (5)
#define QLE_FIELD_INDEX_MY_SIG (6)
#define QLE_FIELD_INDEX_MY_SIG_INFO (7)
#define QLE_FIELD_INDEX_TIME_ON (8)
#define QLE_FIELD_INDEX_TIME_OFF (9)
#define QLE_FIELD_INDEX_QSO_DATE (10)
#define QLE_FIELD_INDEX_QSO_DATE_OFF (11)
#define QLE_FIELD_INDEX_CALL (QLE_NFIELDS - 1 - 1)

struct qle_name_field {
	char *adif_field;
	char *qle_pattern;
	char value[QLE_TOKEN_SIZE];
	void (*transform)(char *dst, char *src, int dstsize);
	int preserve;
};

extern struct qle_name_field qle_fields[];

void qle_rst_defaults(void);
int qle_process_token(char *token);
int qle_process(FILE *input, FILE *output, FILE *error, int compact, int header, char *prelude, time_t input_mtime, char *input_file);

#endif
