/*
    Quick Log Entry (qle)
    Copyright (C) 2025  Thomas Cort

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "check.h"

#include <stdio.h>
#include <stdlib.h>

/*
 * Execute a series of checks in 'checks'
 *
 * Parameters:
 *  checks - a set of checks to execute
 *
 * Returns QLE_CHECK_PASS if all pass, otherwise QLE_CHECK_FAIL on first fail
 */
int qle_check(struct qle_check *checks) {
	int i;

	if (checks == NULL) {
		fprintf(stderr, "check list of checks is NULL\n");
		return QLE_CHECK_FAIL;
	}

	for (i = 0; checks[i].message != NULL; i++) {
		int rc;

		rc = checks[i].fn();
		if (rc == QLE_CHECK_FAIL) {
			fprintf(stderr, "check '%s' failed\n", checks[i].message);
			return QLE_CHECK_FAIL;
		}
	}

	return QLE_CHECK_PASS;
}

