/*
    Quick Log Entry (qle)
    Copyright (C) 2025  Thomas Cort

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "check.h"
#include "../src/re.h"

#include <stdlib.h>
#include <string.h>

static int check_icase_match(void) {
	return qle_match("HELLO", "^HeL+O$") == 1 ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

static int check_icase_nomatch(void) {
	return qle_match("BYTE", "^HeL+O$") == 0 ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

static int check_icase_badpat(void) {
	return qle_match("BYTE", "a{33,31][x]") == -1 ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

int main(int argc, char *argv[]) {

	static struct qle_check checks[] = {
		{ check_icase_match, "qle_match(\"HELLO\", \"^HeL+O$\") --> 1" },
		{ check_icase_nomatch, "qle_match(\"BYTE\", \"^HeL+O$\") --> 0" },
		{ check_icase_badpat, "qle_match(\"BYTE\", \"$^Hi]{]&&*%$%^eL+O$\") --> -1" },
		{ NULL, NULL }
	};

	(void) argc;
	(void) argv;

	return qle_check(checks);
}
