/*
    Quick Log Entry (qle)
    Copyright (C) 2025  Thomas Cort

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

    SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "check.h"
#include "../src/util.h"

#include <stdlib.h>

static int check_min_pos_neg(void) {
	return qle_min( 4, -3) == -3 ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

static int check_min_neg_neg(void) {
	return qle_min(-4, -3) == -4 ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

static int check_min_pos_pos(void) {
	return qle_min( 4,  3) ==  3 ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

static int check_min_neg_pos(void) {
	return qle_min(-4,  3) == -4 ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

static int check_min_same(void) {
	return qle_min(4,  4) == 4 ? QLE_CHECK_PASS : QLE_CHECK_FAIL;
}

int main(int argc, char *argv[]) {

	static struct qle_check checks[] = {
		{ check_min_pos_neg, "min( 4,-3) is -3" },
		{ check_min_neg_neg, "min(-4,-3) is -4" },
		{ check_min_pos_pos, "min( 4, 3) is  3" },
		{ check_min_neg_pos, "min(-4, 3) is -4" },
		{ check_min_same,    "min( 4, 4) is  4" },
		{ NULL, NULL }
	};

	(void) argc;
	(void) argv;

	return qle_check(checks);
}
